@@ -3,7 +3,8 @@
 ###################################################
 ### code chunk number 1: 1dex-1
 ###################################################
-isequal <- function(a, b) {
+isequal <-
+function(a, b) {
     attributes(a) <- NULL
     attributes(b) <- NULL
     if (!isTRUE(all.equal(a, b))) {
@@ -96,7 +97,7 @@ ls1d <- LinStatExpCov(X = model.matrix(~ x - 1), Y = matrix(y, ncol = 1),
 set.seed(29)
 ls1s <- LinStatExpCov(X = as.double(1:5)[x], Y = matrix(y, ncol = 1),
                       nresample = 10, standardise = TRUE)
-ls1c <- lmult(c(1:5), ls1d)
+ls1c <- lmult(1:5, ls1d)
 stopifnot(isequal(ls1c, ls1s))
 set.seed(29)
 ls1d <- LinStatExpCov(X = model.matrix(~ x - 1), Y = matrix(c(y, y), ncol = 2),
@@ -104,7 +105,7 @@ ls1d <- LinStatExpCov(X = model.matrix(~ x - 1), Y = matrix(c(y, y), ncol = 2),
 set.seed(29)
 ls1s <- LinStatExpCov(X = as.double(1:5)[x], Y = matrix(c(y, y), ncol = 2),
                       nresample = 10, standardise = TRUE)
-ls1c <- lmult(c(1:5), ls1d)
+ls1c <- lmult(1:5, ls1d)
 stopifnot(isequal(ls1c, ls1s))
 
 
@@ -149,45 +150,51 @@ r2Xfactor <- rep(1:ncol(y), each = ncol(Xfactor))
 ###################################################
 ### code chunk number 11: Rlibcoin
 ###################################################
-LECV <- function(X, Y, weights = integer(0), subset = integer(0), block = integer(0)) {
+LSEC <-
+function(X, Y, weights = integer(0), subset = integer(0), block = integer(0))
+{
+    if (length(weights) == 0) weights <- rep.int(1, NROW(X))
+    if (length(subset) == 0) subset <- seq_len(NROW(X))
 
-    if (length(weights) == 0) weights <- rep(1, NROW(X))
-    if (length(subset) == 0) subset <- 1:NROW(X)
-    idx <- rep(subset, weights[subset])
-    X <- X[idx,,drop = FALSE]
-    Y <- Y[idx,,drop = FALSE]
-    sumweights <- length(idx)
+    X <- X[subset,, drop = FALSE]
+    Y <- Y[subset,, drop = FALSE]
+    weights <- weights[subset]
 
     if (length(block) == 0) {
-        ExpX <- colSums(X)
-        ExpY <- colSums(Y) / sumweights
-        yc <- t(t(Y) - ExpY)
-        CovY <- crossprod(yc) / sumweights
-        CovX <- crossprod(X)
+        w. <- sum(weights)
+        wX <- weights * X
+        wY <- weights * Y
+        ExpX <- colSums(wX)
+        ExpY <- colSums(wY) / w.
+        CovX <- crossprod(X, wX)
+        Yc <- t(t(Y) - ExpY)
+        CovY <- crossprod(Yc, weights * Yc) / w.
+        T <- crossprod(X, wY)
         Exp <- kronecker(ExpY, ExpX)
-        Cov <- sumweights / (sumweights - 1) * kronecker(CovY, CovX) -
-               1 / (sumweights - 1) * kronecker(CovY, tcrossprod(ExpX))
+        Cov <- w. / (w. - 1) * kronecker(CovY, CovX) -
+                1 / (w. - 1) * kronecker(CovY, tcrossprod(ExpX))
 
-        ret <- list(LinearStatistic = as.vector(crossprod(X, Y)),
-                    Expectation = as.vector(Exp),
-                    Covariance = Cov,
-                    Variance = diag(Cov))
-   } else {
-        block <- block[idx]
-        ret <- list(LinearStatistic = 0, Expectation = 0, Covariance = 0, Variance = 0)
+        list(LinearStatistic = as.vector(T), Expectation = as.vector(Exp),
+             Covariance = Cov, Variance = diag(Cov))
+    } else {
+        block <- block[subset]
+        ret <- list(LinearStatistic = 0, Expectation = 0,
+                    Covariance = 0, Variance = 0)
         for (b in levels(block)) {
-            tmp <- LECV(X = X, Y = Y, subset = which(block == b))
+            tmp <- LSEC(X = X, Y = Y, weights = weights, subset = which(block == b))
             for (l in names(ret)) ret[[l]] <- ret[[l]] + tmp[[l]]
         }
-   }
-   return(ret)
+        ret
+    }
 }
 
 
 ###################################################
 ### code chunk number 12: cmpr
 ###################################################
-cmpr <- function(ret1, ret2) {
+cmpr <-
+function(ret1, ret2)
+{
     if (inherits(ret1, "LinStatExpCov")) {
         if (!ret1$varonly)
             ret1$Covariance <- vcov(ret1)
@@ -213,31 +220,40 @@ LEVxyws <- LinStatExpCov(x, y, weights = weights, subset = subset, varonly = TRU
 ### code chunk number 14: tests
 ###################################################
 ### with X given
-testit <- function(...) {
+testit <-
+function(...)
+{
     a <- LinStatExpCov(x, y, ...)
-    b <- LECV(x, y, ...)
+    b <- LSEC(x, y, ...)
     d <- LinStatExpCov(X = iX2d, ix = ix, Y = iY2d, iy = iy, ...)
-    return(cmpr(a, b) && cmpr(d, b))
+    cmpr(a, b) && cmpr(d, b)
 }
+
 stopifnot(
     testit() && testit(weights = weights) &&
     testit(subset = subset) && testit(weights = weights, subset = subset) &&
     testit(block = block) && testit(weights = weights, block = block) &&
     testit(subset = subset, block = block) &&
-    testit(weights = weights, subset = subset, block = block))
+    testit(weights = weights, subset = subset, block = block)
+)
+
 ### without dummy matrix X
-testit <- function(...) {
+testit <-
+function(...)
+{
     a <- LinStatExpCov(X = ix, y, ...)
-    b <- LECV(Xfactor, y, ...)
+    b <- LSEC(Xfactor, y, ...)
     d <- LinStatExpCov(X = integer(0), ix = ix, Y = iY2d, iy = iy, ...)
-    return(cmpr(a, b) && cmpr(d, b))
+    cmpr(a, b) && cmpr(d, b)
 }
+
 stopifnot(
     testit() && testit(weights = weights) &&
     testit(subset = subset) && testit(weights = weights, subset = subset) &&
     testit(block = block) && testit(weights = weights, block = block) &&
     testit(subset = subset, block = block) &&
-    testit(weights = weights, subset = subset, block = block))
+    testit(weights = weights, subset = subset, block = block)
+)
 
 
 ###################################################
@@ -250,7 +266,9 @@ LinStatExpCov(X = iX2d, ix = ix, Y = iY2d, iy = iy,
 ###################################################
 ### code chunk number 16: quadform
 ###################################################
-MPinverse <- function(x, tol = sqrt(.Machine$double.eps)) {
+MPinverse <-
+function(x, tol = sqrt(.Machine$double.eps))
+{
     SVD <- svd(x)
     pos <- SVD$d > max(tol * SVD$d[1L], 0)
     inv <- SVD$v[, pos, drop = FALSE] %*%
@@ -258,7 +276,9 @@ MPinverse <- function(x, tol = sqrt(.Machine$double.eps)) {
     list(MPinv = inv, rank = sum(pos))
 }
 
-quadform <- function (linstat, expect, MPinv) {
+quadform <-
+function(linstat, expect, MPinv)
+{
     censtat <- linstat - expect
     censtat %*% MPinv %*% censtat
 }
@@ -277,11 +297,13 @@ stopifnot(isequal(qf1, qf2))
 ### code chunk number 17: ExpectationInfluence
 ###################################################
 sumweights <- sum(weights[subset])
-expecty <- a0 <- colSums(y[subset, ] * weights[subset]) / sumweights
-a1 <- .Call(libcoin:::R_ExpectationInfluence, y, weights, subset);
-a2 <- .Call(libcoin:::R_ExpectationInfluence, y, as.double(weights), as.double(subset));
-a3 <- .Call(libcoin:::R_ExpectationInfluence, y, weights, as.double(subset));
-a4 <- .Call(libcoin:::R_ExpectationInfluence, y, as.double(weights), subset);
+expecty <- colSums(y[subset, ] * weights[subset]) / sumweights
+
+a0 <- expecty
+a1 <- .Call(libcoin:::R_ExpectationInfluence, y, weights, subset)
+a2 <- .Call(libcoin:::R_ExpectationInfluence, y, as.double(weights), as.double(subset))
+a3 <- .Call(libcoin:::R_ExpectationInfluence, y, weights, as.double(subset))
+a4 <- .Call(libcoin:::R_ExpectationInfluence, y, as.double(weights), subset)
 a5 <- LinStatExpCov(x, y, weights = weights, subset = subset)$ExpectationInfluence
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
@@ -299,23 +321,24 @@ r2y <- rep(1:ncol(y), each = ncol(y))
 a0 <- colSums(yc[subset, r1y] * yc[subset, r2y] * weights[subset]) / sumweights
 a0 <- matrix(a0, ncol = ncol(y))
 vary <- diag(a0)
+
 a0 <- a0[lower.tri(a0, diag = TRUE)]
-a1 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, subset, 0L);
-a2 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), as.double(subset), 0L);
-a3 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, as.double(subset), 0L);
-a4 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), subset, 0L);
+a1 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, subset, 0L)
+a2 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), as.double(subset), 0L)
+a3 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, as.double(subset), 0L)
+a4 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), subset, 0L)
 a5 <- LinStatExpCov(x, y, weights = weights, subset = subset)$CovarianceInfluence
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4) &&
           isequal(a0, a5))
 
-a1 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, subset, 1L);
-a2 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), as.double(subset), 1L);
-a3 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, as.double(subset), 1L);
-a4 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), subset, 1L);
-a5 <- LinStatExpCov(x, y, weights = weights, subset = subset, varonly = TRUE)$VarianceInfluence
 a0 <- vary
+a1 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, subset, 1L)
+a2 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), as.double(subset), 1L)
+a3 <- .Call(libcoin:::R_CovarianceInfluence, y, weights, as.double(subset), 1L)
+a4 <- .Call(libcoin:::R_CovarianceInfluence, y, as.double(weights), subset, 1L)
+a5 <- LinStatExpCov(x, y, weights = weights, subset = subset, varonly = TRUE)$VarianceInfluence
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4) &&
@@ -326,39 +349,37 @@ stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
 ### code chunk number 19: ExpectationCovarianceX
 ###################################################
 a0 <- colSums(x[subset, ] * weights[subset])
-a0
 a1 <- .Call(libcoin:::R_ExpectationX, x, P, weights, subset);
-a2 <- .Call(libcoin:::R_ExpectationX, x, P, as.double(weights), as.double(subset));
-a3 <- .Call(libcoin:::R_ExpectationX, x, P, weights, as.double(subset));
-a4 <- .Call(libcoin:::R_ExpectationX, x, P, as.double(weights), subset);
+a2 <- .Call(libcoin:::R_ExpectationX, x, P, as.double(weights), as.double(subset))
+a3 <- .Call(libcoin:::R_ExpectationX, x, P, weights, as.double(subset))
+a4 <- .Call(libcoin:::R_ExpectationX, x, P, as.double(weights), subset)
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4) &&
           isequal(a0, LECVxyws$ExpectationX))
 
 a0 <- colSums(x[subset, ]^2 * weights[subset])
-a1 <- .Call(libcoin:::R_CovarianceX, x, P, weights, subset, 1L);
-a2 <- .Call(libcoin:::R_CovarianceX, x, P, as.double(weights), as.double(subset), 1L);
-a3 <- .Call(libcoin:::R_CovarianceX, x, P, weights, as.double(subset), 1L);
-a4 <- .Call(libcoin:::R_CovarianceX, x, P, as.double(weights), subset, 1L);
+a1 <- .Call(libcoin:::R_CovarianceX, x, P, weights, subset, 1L)
+a2 <- .Call(libcoin:::R_CovarianceX, x, P, as.double(weights), as.double(subset), 1L)
+a3 <- .Call(libcoin:::R_CovarianceX, x, P, weights, as.double(subset), 1L)
+a4 <- .Call(libcoin:::R_CovarianceX, x, P, as.double(weights), subset, 1L)
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4))
 
 a0 <- as.vector(colSums(Xfactor[subset, ] * weights[subset]))
-a0
-a1 <- .Call(libcoin:::R_ExpectationX, ix, Lx, weights, subset);
-a2 <- .Call(libcoin:::R_ExpectationX, ix, Lx, as.double(weights), as.double(subset));
-a3 <- .Call(libcoin:::R_ExpectationX, ix, Lx, weights, as.double(subset));
-a4 <- .Call(libcoin:::R_ExpectationX, ix, Lx, as.double(weights), subset);
+a1 <- .Call(libcoin:::R_ExpectationX, ix, Lx, weights, subset)
+a2 <- .Call(libcoin:::R_ExpectationX, ix, Lx, as.double(weights), as.double(subset))
+a3 <- .Call(libcoin:::R_ExpectationX, ix, Lx, weights, as.double(subset))
+a4 <- .Call(libcoin:::R_ExpectationX, ix, Lx, as.double(weights), subset)
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4))
 
-a1 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, subset, 1L);
-a2 <- .Call(libcoin:::R_CovarianceX, ix, Lx, as.double(weights), as.double(subset), 1L);
-a3 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, as.double(subset), 1L);
-a4 <- .Call(libcoin:::R_CovarianceX, ix, Lx, as.double(weights), subset, 1L);
+a1 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, subset, 1L)
+a2 <- .Call(libcoin:::R_CovarianceX, ix, Lx, as.double(weights), as.double(subset), 1L)
+a3 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, as.double(subset), 1L)
+a4 <- .Call(libcoin:::R_CovarianceX, ix, Lx, as.double(weights), subset, 1L)
 
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4))
@@ -368,8 +389,8 @@ r2x <- rep(1:ncol(Xfactor), each = ncol(Xfactor))
 a0 <- colSums(Xfactor[subset, r1x] * Xfactor[subset, r2x] * weights[subset])
 a0 <- matrix(a0, ncol = ncol(Xfactor))
 vary <- diag(a0)
-a0 <- a0[lower.tri(a0, diag = TRUE)]
 
+a0 <- a0[lower.tri(a0, diag = TRUE)]
 a1 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, subset, 0L)
 a2 <- .Call(libcoin:::R_CovarianceX, ix, Lx, as.double(weights), as.double(subset), 0L)
 a3 <- .Call(libcoin:::R_CovarianceX, ix, Lx, weights, as.double(subset), 0L)
@@ -387,6 +408,7 @@ a1 <- .Call(libcoin:::R_Sums, N, weights, subset)
 a2 <- .Call(libcoin:::R_Sums, N, as.double(weights), as.double(subset))
 a3 <- .Call(libcoin:::R_Sums, N, weights, as.double(subset))
 a4 <- .Call(libcoin:::R_Sums, N, as.double(weights), subset)
+
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4))
 
@@ -397,7 +419,7 @@ stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
 r1 <- rep(1:ncol(x), ncol(y))
 r2 <- rep(1:ncol(y), each = ncol(x))
 
-a0 <- colSums(x[subset,r1] * y[subset,r2] * weights[subset])
+a0 <- colSums(x[subset, r1] * y[subset, r2] * weights[subset])
 a1 <- .Call(libcoin:::R_KronSums, x, P, y, weights, subset, 0L)
 a2 <- .Call(libcoin:::R_KronSums, x, P, y, as.double(weights), as.double(subset), 0L)
 a3 <- .Call(libcoin:::R_KronSums, x, P, y, weights, as.double(subset), 0L)
@@ -406,8 +428,8 @@ a4 <- .Call(libcoin:::R_KronSums, x, P, y, as.double(weights), subset, 0L)
 stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
           isequal(a0, a3) && isequal(a0, a4))
 
-a0 <- as.vector(colSums(Xfactor[subset,r1Xfactor] *
-                        y[subset,r2Xfactor] * weights[subset]))
+a0 <- as.vector(colSums(Xfactor[subset, r1Xfactor] *
+                        y[subset, r2Xfactor] * weights[subset]))
 a1 <- .Call(libcoin:::R_KronSums, ix, Lx, y, weights, subset, 0L)
 a2 <- .Call(libcoin:::R_KronSums, ix, Lx, y, as.double(weights), as.double(subset), 0L)
 a3 <- .Call(libcoin:::R_KronSums, ix, Lx, y, weights, as.double(subset), 0L)
@@ -420,21 +442,23 @@ stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
 ###################################################
 ### code chunk number 22: KronSums-Permutation
 ###################################################
-a0 <- colSums(x[subset,r1] * y[subsety, r2])
+a0 <- colSums(x[subset, r1] * y[subsety, r2])
 a1 <- .Call(libcoin:::R_KronSums_Permutation, x, P, y, subset, subsety)
 a2 <- .Call(libcoin:::R_KronSums_Permutation, x, P, y, as.double(subset), as.double(subsety))
+
 stopifnot(isequal(a0, a1) && isequal(a0, a2))
 
-a0 <- as.vector(colSums(Xfactor[subset,r1Xfactor] * y[subsety, r2Xfactor]))
+a0 <- as.vector(colSums(Xfactor[subset, r1Xfactor] * y[subsety, r2Xfactor]))
 a1 <- .Call(libcoin:::R_KronSums_Permutation, ix, Lx, y, subset, subsety)
 a2 <- .Call(libcoin:::R_KronSums_Permutation, ix, Lx, y, as.double(subset), as.double(subsety))
+
 stopifnot(isequal(a0, a1) && isequal(a0, a2))
 
 
 ###################################################
 ### code chunk number 23: colSums
 ###################################################
-a0 <- colSums(x[subset,] * weights[subset])
+a0 <- colSums(x[subset, ] * weights[subset])
 a1 <- .Call(libcoin:::R_colSums, x, weights, subset)
 a2 <- .Call(libcoin:::R_colSums, x, as.double(weights), as.double(subset))
 a3 <- .Call(libcoin:::R_colSums, x, weights, as.double(subset))
@@ -494,8 +518,10 @@ stopifnot(isequal(a0, a1) && isequal(a0, a2) &&
 ### code chunk number 27: blocks
 ###################################################
 sb <- sample(block)
-ns1 <- do.call("c", tapply(subset, sb[subset], function(i) i))
+
+ns1 <- do.call(c, tapply(subset, sb[subset], function(i) i))
 ns2 <- .Call(libcoin:::R_order_subset_wrt_block, y, integer(0), subset, sb)
+
 stopifnot(isequal(ns1, ns2))
 
 
@@ -504,8 +530,10 @@ stopifnot(isequal(ns1, ns2))
 ###################################################
 A <- matrix(runif(12), ncol = 3)
 B <- matrix(runif(10), ncol = 2)
+
 K1 <- kronecker(A, B)
 K2 <- .Call(libcoin:::R_kronecker, A, B)
+
 stopifnot(isequal(K1, K2))
 
 
