@@ -28,8 +28,12 @@ cmp <- function(t1, t2) {
         var2 <- var2[!upper.tri(var2)]
     }
     stopifnot(all.equal(
-        list(t1$LinearStatistic, t1$Expectation, var1),
-        list(t2@statistic@linearstatistic, t2@statistic@expectation, var2),
+        list(t1$LinearStatistic,
+             t1$Expectation,
+             var1),
+        list(as.vector(statistic(t2, type = "linear")),
+             as.vector(expectation(t2)),
+             var2),
         check.attributes = FALSE, tolerance = tol
     ))
 }
@@ -50,8 +54,8 @@ cmp4 <- function(t1, t2)
     stopifnot(all.equal(t1$TestStatistic, sqrt(t2$TestStatistic), tolerance = tol))
 
 
-t1 <-LinStatExpCov(X, Y)
-t1v <-LinStatExpCov(X, Y, varonly = TRUE)
+t1 <- LinStatExpCov(X, Y)
+t1v <- LinStatExpCov(X, Y, varonly = TRUE)
 t2 <- independence_test(Y ~ X)
 cmp(t1, t2)
 cmp(t1v, t2)
@@ -63,8 +67,8 @@ cmp3(t3, doTest(t1, teststat = "maximum", alternative = "greater"), pvalue = TRU
 t3 <- independence_test(Y ~ X, teststat = "quadratic")
 cmp3(t3, doTest(t1, teststat = "quadratic"), pvalue = TRUE)
 
-t1 <-LinStatExpCov(X, Y, weights = w)
-t1v <-LinStatExpCov(X, Y, weights = w, varonly = TRUE)
+t1 <- LinStatExpCov(X, Y, weights = w)
+t1v <- LinStatExpCov(X, Y, weights = w, varonly = TRUE)
 t2 <- independence_test(Y ~ X, weights = ~ w)
 cmp(t1, t2)
 cmp(t1v, t2)
@@ -176,23 +180,23 @@ w <- as.integer(floor(runif(n, max = 4)))
 s <- sort(sample(1:n, floor(n/2), replace = TRUE))
 b <- sample(gl(2, 2, length = n))
 
-t1 <-LinStatExpCov(X, Y)
-t1v <-LinStatExpCov(X, Y, varonly = TRUE)
+t1 <- LinStatExpCov(X, Y)
+t1v <- LinStatExpCov(X, Y, varonly = TRUE)
 t2 <- independence_test(Y ~ X)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y)
-t1vf <-LinStatExpCov(fx, Y, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y)
+t1vf <- LinStatExpCov(fx, Y, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
-t1 <-LinStatExpCov(X, Y, weights = w)
-t1v <-LinStatExpCov(X, Y, weights = w, varonly = TRUE)
+t1 <- LinStatExpCov(X, Y, weights = w)
+t1v <- LinStatExpCov(X, Y, weights = w, varonly = TRUE)
 t2 <- independence_test(Y ~ X, weights = ~ w)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, weights = w)
-t1vf <-LinStatExpCov(fx, Y, weights = w, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, weights = w)
+t1vf <- LinStatExpCov(fx, Y, weights = w, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -201,8 +205,8 @@ t1v <- LinStatExpCov(X, Y, subset = s, varonly = TRUE)
 t2 <- independence_test(Y ~ X, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, subset = s)
-t1vf <-LinStatExpCov(fx, Y, subset = s, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, subset = s)
+t1vf <- LinStatExpCov(fx, Y, subset = s, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -211,8 +215,8 @@ t1v <- LinStatExpCov(X, Y, weights = w, subset = s, varonly = TRUE)
 t2 <- independence_test(Y ~ X, weights = ~w, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, weights = w, subset = s)
-t1vf <-LinStatExpCov(fx, Y, weights = w, subset = s, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, weights = w, subset = s)
+t1vf <- LinStatExpCov(fx, Y, weights = w, subset = s, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -221,8 +225,8 @@ t1v <- LinStatExpCov(X, Y, block = b, varonly = TRUE)
 t2 <- independence_test(Y ~ X  | b)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, block = b)
-t1vf <-LinStatExpCov(fx, Y, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, block = b)
+t1vf <- LinStatExpCov(fx, Y, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -232,8 +236,8 @@ t1v <- LinStatExpCov(X, Y, weights = w, block = b, varonly = TRUE)
 t2 <- independence_test(Y ~ X | b, weights = ~ w)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, weights = w, block = b)
-t1vf <-LinStatExpCov(fx, Y, weights = w, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, weights = w, block = b)
+t1vf <- LinStatExpCov(fx, Y, weights = w, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -242,8 +246,8 @@ t1v <- LinStatExpCov(X, Y, subset = s, block = b, varonly = TRUE)
 t2 <- independence_test(Y ~ X | b, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, subset = s, block = b)
-t1vf <-LinStatExpCov(fx, Y, subset = s, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, subset = s, block = b)
+t1vf <- LinStatExpCov(fx, Y, subset = s, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -252,8 +256,8 @@ t1v <- LinStatExpCov(X, Y, weights = w, subset = s, block = b, varonly = TRUE)
 t2 <- independence_test(Y ~ X | b, weights = ~w, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(fx, Y, weights = w, subset = s, block = b)
-t1vf <-LinStatExpCov(fx, Y, weights = w, subset = s, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(fx, Y, weights = w, subset = s, block = b)
+t1vf <- LinStatExpCov(fx, Y, weights = w, subset = s, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -275,8 +279,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, varonly = TRUE)
 t2 <- independence_test(YY ~ XX)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -285,8 +289,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, weights = w, varonly = TRUE)
 t2 <- independence_test(YY ~ XX, weights = ~ w)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -295,8 +299,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, subset = s, varonly = TRUE)
 t2 <- independence_test(YY ~ XX, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, subset = s)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, subset = s, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, subset = s)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, subset = s, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -306,8 +310,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, weights = w, subset = s, varonly = TRUE)
 t2 <- independence_test(YY ~ XX, weights = ~w, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -316,8 +320,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, block = b, varonly = TRUE)
 t2 <- independence_test(YY ~ XX  | b)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, block = b)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, block = b)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -326,8 +330,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, weights = w, block = b, varonly = TRUE)
 t2 <- independence_test(YY ~ XX | b, weights = ~ w)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, block = b)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, block = b)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -336,8 +340,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, subset = s, block = b, varonly = TRUE)
 t2 <- independence_test(YY ~ XX | b, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, subset = s, block = b)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, subset = s, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, subset = s, block = b)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, subset = s, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
@@ -346,8 +350,8 @@ t1v <- LinStatExpCov(X, Y, ix, iy, weights = w, subset = s, block = b, varonly =
 t2 <- independence_test(YY ~ XX| b, weights = ~w, subset = s)
 cmp(t1, t2)
 cmp(t1v, t2)
-t1f <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, block = b)
-t1vf <-LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, block = b, varonly = TRUE)
+t1f <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, block = b)
+t1vf <- LinStatExpCov(numeric(0), Y, ix, iy, weights = w, subset = s, block = b, varonly = TRUE)
 cmp2(t1, t1f)
 cmp2(t1v, t1vf)
 
